@@ -8,7 +8,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 
 our $VERSION;
-$VERSION = sprintf "%d.%02d", q$Name: Release-1-03 $ =~ /Release-(\d+)-(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Name: Release-1-04 $ =~ /Release-(\d+)-(\d+)/;
 
 our @EXPORT = qw();
 #our @EXPORT_OK = qw();
@@ -148,8 +148,9 @@ sub nam_get {
 
 	my (@in, @out);
 	if ($#_ < 0) {			# if no args, get all files starting
-	#	@in = bsd_glob($dir . '[0-9]=*');	# "<digit>=..."
-		@in = bsd_glob(catfile($dir, '[0-9]=*'));	# "<digit>=..."
+		# Surprisingly, with bsd_glob a / separator works in Win32
+		@in = bsd_glob("$dir/[0-9]=*");	# so no need for catfile()
+	#	@in = bsd_glob(catfile($dir, '[0-9]=*'));	# "<digit>=..."
 		-e $dir_type and		# since we're getting all,
 			unshift @in, $dir_type;	# if it exists, add .dir_type
 	}
@@ -161,10 +162,11 @@ sub nam_get {
 				next		# next if only .dir_type
 					if $n eq ".";
 			}
-			#push @in, bsd_glob($dir . $_ . '=*')
-			push @in, bsd_glob(catfile($dir, $n . '=*'));
+			push @in, bsd_glob("$dir/$n=*");
+			#push @in, bsd_glob(catfile($dir, $n . '=*'));
 		}
 	}
+	# Now create the output array.
 	my ($number, $fname, $fvalue, $status, $regex);
 	while (defined($fname = shift(@in))) {
 
@@ -173,33 +175,37 @@ sub nam_get {
 		#($number) = ($fname =~ m{^$dir(\d*)=});
 		#$regex = catfile($dir, '(\d*)=');
 
-		# ask for a dummy file 'x' in order to get a dir separator
-		#
-		$regex = catfile($dir, 'x');	# separator might be \ or /
+#		# ask for a dummy file 'x' in order to get a dir separator
+#		#
+#		$regex = catfile($dir, 'x');	# separator might be \ or /
 # temporary crap to flush out bug in Windows version
 #$regex =~ s,/,\\,g;
 #$fname =~ s,/,\\,g;
-		$regex =~ s/\\/\\\\/g;	# preserve any \ separators for regex
-
-		# replace dummy file with pattern we want, leaving separator
-		#
-		$regex =~ s/x$/(\\d*)=/;	# replace with literal pattern
+#		$regex =~ s/\\/\\\\/g;	# preserve any \ separators for regex
+#
+#		# replace dummy file with pattern we want, leaving separator
+#		#
+#		$regex =~ s/x$/(\\d*)=/;	# replace with literal pattern
 #print "xxx regex=$regex\n";
-		($number) = ($fname =~ m{^$regex});
+#		($number) = ($fname =~ m{^$regex});
 #print "xxx number=$number, fname=$fname\n";
+		($number) = ($fname =~ m{^$dir/(\d*)=});
 
 		# if there's no number matched, it may be for .dir_type,
 		# in which case use "." for number, else give up with ""
 		#
-		$regex = catfile($dir, $dtname);
+#		$regex = catfile($dir, $dtname);
 #$regex =~ s,/,\\,g;
-		$regex =~ s/\\/\\\\/g;	# preserve any \ separators for regex
+#		$regex =~ s/\\/\\\\/g;	# preserve any \ separators for regex
 #print "xxx dtname=$dtname, regex=$regex\n";
 		#$number = ($fname =~ m{^$dir$dtname} ? "." : "")
 		# yyy matching on $dtname is imperfect if it contains
 		#     a '.' -- eg, ".dir_type" matches "adir_type"
 		# contains a
-		$number = ($fname =~ m{^$regex} ? "." : "")
+		#$number = ($fname =~ m{^$regex} ? "." : "")
+
+		# \Q prevents chars in $dtname (eg, '.') being used in regex
+		$number = ($fname =~ m{^$dir/\Q$dtname\E} ? "." : "")
 			if (! defined($number));
 
 		push @out, $number, $fname, ($status ? $status : $fvalue);
